@@ -3,5 +3,8 @@ from .writer import (
     MZ_ARRAY, INTENSITY_ARRAY, CHARGE_ARRAY,
     compression_map, default_cv_list)
 
+from .binary_encoding import compressors
+
+
 __all__ = ["MzMLWriter", "ARRAY_TYPES", "compression_map", "default_cv_list",
-           "MZ_ARRAY", "INTENSITY_ARRAY", "CHARGE_ARRAY", ]
+           "MZ_ARRAY", "INTENSITY_ARRAY", "CHARGE_ARRAY", 'compressors']
