@@ -52,6 +52,9 @@ class IndexedMzML(TagBase):
 
 class ComponentDispatcher(XMLBindingDispatcherBase):
 
+    _native_id_maker = None
+    native_id_format = None
+
     def __init__(self, *args, **kwargs):
         super(
             ComponentDispatcher,
@@ -132,6 +135,11 @@ class SourceFileList(GenericCollection):
         super(SourceFileList, self).__init__(
             'sourceFileList', members, context)
 
+    @property
+    def native_id_formats(self):
+        formats = list({fid.id: fid for f in self for fid in f.native_id_format}.values())
+        return formats
+
 
 class SourceFile(ComponentBase):
     requires_id = True
@@ -181,6 +189,19 @@ class SourceFile(ComponentBase):
     def write_content(self, xml_file):
         self.write_params(xml_file)
 
+    @property
+    def native_id_format(self):
+        formats = []
+        for param in self.params:
+            param = self.context.param(param)
+            try:
+                term = self.context.term(param.accession)
+            except (AttributeError, KeyError):
+                continue
+            if term.is_of_type("MS:1000767"):
+                formats.append(term)
+        return formats
+
 
 class FileDescription(ComponentBase):
     requires_id = False
@@ -204,6 +225,10 @@ class FileDescription(ComponentBase):
         self.context = context
         self.element = _element('fileDescription')
 
+    @property
+    def native_id_formats(self):
+        return self.source_files.native_id_formats
+
     def write_content(self, xml_file):
         self.content.write(xml_file)
         self.source_files.write(xml_file)
@@ -604,7 +629,8 @@ class Spectrum(ComponentBase):
             index=index,
             sourceFileRef=self._source_file_reference,
             defaultArrayLength=self.default_array_length,
-            dataProcessingRef=self._data_processing_reference)
+            dataProcessingRef=self._data_processing_reference,
+            id_formatter=context['native_id_formatter'])
         self.context = context
         self.context['Spectrum'][id] = self.element.id
         self.params = self.prepare_params(params, **kwargs)
